@@ -5,11 +5,12 @@ from multiprocessing.synchronize import Event
 from os import get_terminal_size
 from pathlib import Path
 from typing import Optional, Callable, Tuple, Any
-from pprint import pprint
+from pprint import pformat
 
 import click
 from legion_utils import Priority
 from robotnikmq import RobotnikConfig, Subscriber, Message
+from termcolor import colored
 from typeguard import typechecked
 
 DEFAULT_CONFIG = Path.cwd() / 'config.yaml'
@@ -37,16 +38,30 @@ class MessagePrinter:
     def term_width(self) -> int:
         return get_terminal_size().columns
 
+    def _priority_color(self, msg: Message) -> Optional[str]:
+        if msg.contents['priority'] == 1:
+            return 'blue'
+        if msg.contents['priority'] == 2:
+            return 'yellow'
+        if msg.contents['priority'] == 3:
+            return 'red'
+        if msg.contents['priority'] == 4:
+            return 'purple'
+        return None
+
     @lru_cache
     def _label(self, msg: Message) -> str:
         return f"{Priority(msg.contents['priority']).name}: {msg.timestamp.format()}"
 
+    def _header(self, msg: Message) -> str:
+        width = self.term_width
+        return f"{'=' * ((width - 2 - len(self._label(msg))) // 2 + 1)} {self._label(msg)} {'=' * ((width - 2 - len(self._label(msg))) // 2 - (1 if len(self._label(msg)) % 2 == 0 else 0))}"
+
     @typechecked
     def watch(self, msg: Message) -> None:
-        width = self.term_width
-        print(f"{'=' * ((width - 2 - len(self._label(msg))) // 2 + 1)} {self._label(msg)} {'=' * ((width - 2 - len(self._label(msg))) // 2)}")
-        pprint(msg.contents)
-        print('=' * width)
+        print(colored(self._header(msg), self._priority_color(msg)))
+        print(colored(pformat(msg.contents), self._priority_color(msg)))
+        print(colored('=' * self.term_width, self._priority_color(msg)))
         if self.num_msgs is not None:  # pragma: no cover
             self.num_msgs -= 1
             if self.num_msgs <= 0 and self.msg_limit_received is not None:
